@@ -1,5 +1,5 @@
-# @CODE:TRUST-001 | SPEC: SPEC-TRUST-001.md
-"""TRUST 검증기 패키지"""
+# @CODE:TRUST-001 | SPEC: SPEC-TRUST-001/spec.md
+"""TRUST validator package"""
 
 from moai_adk.core.quality.validators.base_validator import ValidationResult
 
